<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="de" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Torrent starten</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Prüfsummenkontrolle überspringen</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Erstelle Unterordner</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modus für das Torrent-Management:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Ohne Kategorie</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Kategorie hinzufügen ...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Kategorie entfernen</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Unbenutzte Kategorien entfernen</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrents fortsetzen</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrents pausieren</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrents löschen</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Neue Kategorie</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Kategorie ändern ...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>qBittorrent beenden</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Nur ein Link pro Zeile</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Die globale Begrenzung der Uploadrate muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Die globale Begrenzung der Downloadrate muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Die alternative Begrenzung der Uploadrate muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Die alternative Begrenzung der Downloadrate muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Die Anzahl der maximal aktiven Downloads muss mindestens 0 sein.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Die Anzahl der maximal aktiven Uploads muss mindestens 0 sein.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Die Anzahl der maximal aktiven Torrents muss mindestens 0 sein.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Maximale Anzahl der Verbindungen muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Maximale Anzahl der Verbindungen pro Torrent muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Maximale Anzahle der Upload-Slots muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Programmeinstellungen konnten nicht gespeichert werden – qBittorrent ist vermutlich nicht erreichbar.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent auf Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Das Shareverhältnis muss zwischen 0 und 9998 sein.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Die Grenze für die Seedzeit muss zwischen 0 und 525600 Minuten liegen.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Der Port für eingehende Verbindungen muss zwischen 1 und 65535 liegen.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Der Port für das Webinterface muss zwischen 1 und 65535 liegen.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Fehler beim Einloggen – vermutlich ist qBittorrent nicht erreichbar.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Ungültiger Benutzername oder Passwort.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Ursprüngliche Entwickler</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Torrents hochladen</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Datei(en) hierhin speichern:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Verzeichnisnamen eingeben</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mehr Informationen</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Information über Zertifikate</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Speicherort setzen</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Uploadrate begrenzen</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Downloadrate begrenzen</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Torrent umbenennen</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Andere ...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Torrents von URL oder Magnet-Link herunterladen</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Lokalen Torrent hochladen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Sollen die die ausgewählten Torrents wirklich aus der Transfer-Liste gelöscht werden?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent-Programm ist nicht erreichbar</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Die Gesamtanzahl der Upload-Slots muss größer als 0 sein oder deaktiviert werden.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Ungültiger Kategoriename:\nBitte keine Sonderzeichen im Kategorienamen verwenden.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kategorie konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Der UL-Schwellenwert muss größer als 0 sein.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Freier Platz:  %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Der Inaktivitäts-Timer für Torrents muss größer als 0 sein.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Speicherverwaltung</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Der DL-Schwellenwert muss größer als 0 sein.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent wurde beendet</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Optionen ...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Niedrigste Priorität</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Höchste Priorität</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Priorität verringern</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Priorität erhöhen</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Obere Werkzeugleiste</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Status Bar</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Geschwindigkeit in der Titelleiste</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Entwicklung unterstützen!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Alle fortsetzen</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiken </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Alle anhalten</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Torrent-Datei hinzufügen...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentation</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Torrent-Link hinzufügen...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Globale Begrenzung der Uploadgeschwindigkeit</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Globale Begrenzung der Downloadgeschwindigkeit</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Sind Sie sicher, dass sie qBittorrent beenden möchten?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternative Geschwindigkeitsbegrenzung</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Suchmaschine</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Torrent-Liste filtern ...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Übertragungen</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Weboberfläche</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Benutzeroberflächensprache:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Benachrichtigen, wenn der Download fertig ist</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Externes Programm aufrufen, wenn der Torrent fertig ist</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-Filterung</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Benutzung von alternativen Verhältnisbegrenzungen verwenden</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Warteschlange für Torrents</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Torrents seeden, bis deren Seedverhältnis erreicht wurde</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Diese Tracker automatisch zu neuen Downloads hinzufügen:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Webuser-Interface (Fernbedienung)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-Adresse:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Server Domains:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTPS anstatt von HTTP benutzen</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Authentifizierung für Clients auf dem Localhost umgehen</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Authentifizierung für Clients auf der Liste der erlaubten IP-Subnets umgehen</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Dynamischen Domainnamen aktualisieren</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Unvollständige Torrents speichern in:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>.torrent Dateien kopieren nach:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopiere die .torrent Dateien von beendeten Downloads nach:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Allen Dateien Speicherplatz im Vorhinein zuweisen</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>.!qB Erweiterung für unvollständige Dateien verwenden</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>.torrent-Dateien aus diesem Verzeichnis automatisch hinzufügen:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-Server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Dieser Server benötigt eine sichere Verbindung (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Aktiviertes Protokoll:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP und μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port auf dem gelauscht wird</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port für eingehende Verbindungen:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>UPnP / NAT-PMP Portweiterleitung des Routers verwenden</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Bei jedem Anwendungsstart einen anderen Port verwenden</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Verbindungsbeschränkungen</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maximale Anzahl der Verbindungen pro Torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Maximale globale Anzahl der Verbindungen:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maximale Anzahl Upload-Slots pro Torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Maximale globale Anzahl von Upload-Slots:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy-Server</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Keiner)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Proxy für Peer-Verbindungen verwenden</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Deaktiviere Verbindungen die nicht von Proxys unterstützt werden</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Proxy nur für Torrents verwenden</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filterpfad (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuell gebannte IP-Adressen...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Zu Trackern hinzufügen</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globale Verhältnisbegrenzung</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Hochladen:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Herunterladen:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternative Verhältnisbegrenzungen</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Von:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>An:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Wann:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Jeden Tag</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Wochentage</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Wochenenden</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Einstellungen für Verhältnisbegrenzungen</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Verhältnisbegrenzung auf Transport Overhead anwenden</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Verhältnisbegrenzung für das µTP-Protokoll verwenden</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privatsphäre</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>DHT (dezentralisiertes Netzwerk) aktivieren, um mehr Peers zu finden</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Peer Exchange (PeX) aktivieren, um mehr Peers zu finden</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Lokale Peer Auffindung (LPD) aktivieren um mehr Peers zu finden</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Verschlüsselungsmodus:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Verschlüsselung bevorzugen</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Verschlüsselung verlangen</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Verschlüsselung deaktivieren</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Anonymen Modus aktivieren</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maximal aktive Downloads:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maximal aktive Uploads:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maximal aktive Torrents:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Bei diesen Begrenzungen langsame Torrents nicht mit einbeziehen</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Shareverhältnis-Begrenzung</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Torrents seeden, bis dieses Verhältnis erreicht wurde</translation>
    </message>
    <message>
        <source>then</source>
        <translation>dann</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>UPnP / NAT-PMP um den Port des Routers weiterzuleiten</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Zertifikat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Schlüssel:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrieren</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domainname:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Unterstützte Parameter (Groß-/Kleinschreibung beachten):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentname</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategorie</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Label (getrennt durch Komma)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Inhaltspfad (gleich wie der Hauptpfad für Mehrdateien-Torrent)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Hauptpfad (erster Pfad für das Torrent-Unterverzeichnis)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Speicherpfad</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Anzahl der Dateien</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrentgröße (Byte)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: aktueller Tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info-Hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tipp: Setze Parameter zwischen Anführungszeichen damit Text bei Leerzeichen nicht abgeschnitten wird (z.B. "%N").</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Der Benutzername für das Webinterface muss mindestens 3 Zeichen lang sein.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Das Passwort für das Webinterface muss mindestens 6 Zeichen lang sein.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Clickjacking-Schutz aktivieren</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>CSRF-Schutz aktivieren (Cross-Site Request Forgery)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>.torrent-Dateien anschließend löschen</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>DL-Schwellenwert:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>UL-Schwellenwert:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Aktuelles Passwort ändern</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Verwende alternatives Webinterface</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Standardspeicherpfad:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Der Speicherort des alternativen Webinterface darf nicht leer sein.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Download nicht automatisch starten</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Wechsle den Torrent in den manuellen Modus</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Wenn die Torrent-Kategorie geändert wird:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Betroffene Torrents verschieben</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Verhältnisbegrenzung für Peers im LAN verwenden</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 bedeutet unbegrenzt</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Torrent verschieben</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Wenn sich der Standardspeicherpfad ändert:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Host-Header Überprüfung einschalten</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Wenn sich der Speicherpfad der Kategorie ändert:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Unterordner für Torrents anlegen, die aus mehreren Dateien bestehen</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Wechsle betroffene Torrents in den manuellen Modus</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Speicherort der Dateien:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Timer für Torrent-Inaktivität:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Vorgabe-Modus für das Torrent-Management:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Sobald ein Torrent hinzugefügt wird</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flags</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>DL-Rate</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>UL-Rate</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Runtergeladen</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Hochgeladen</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevanz</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Dateien</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Land</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-Quellen</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Runtergeladen:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Übertragungen</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktiv seit:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Fertig in:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Hochgeladen:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>DL-Geschwindigkeit:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>UL-Geschwindigkeit:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Peers:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Grenze für Download:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Grenze für Upload:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Verworfen:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Verbindungen:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Share Verhältnis:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Erneute Anmeldung in:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Letzter Seeder (100%) gesehen:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Gesamtgröße:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Teile:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Erstellt von:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Hinzugefügt am:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Abgeschlossen am:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Erstellt am:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent Prüfsumme:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Speicherpfad:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Niemals</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (%3 fertig)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 diese Sitzung)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 max.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 gesamt)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 durchschn.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Grenze für Download:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Grenze für Upload:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Beobachtetes Verzeichnis</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Anderer Speicherort</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Beobachtetes Verzeichnis</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Standardspeicherort</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistiken </translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Benutzer-Statistiken </translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistik für Zwischenspeicher</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Zugriffe Lesepuffer:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Durchschnittliche Zeit in Warteschlange:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Verbundene Peers:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Gesamte Share-Rate:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Gesamter DL:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Abfall in dieser Sitzung:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Gesamter UL:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Gesamte Buffergröße:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Leistungsstatistik</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Eingereihte I/O Aufgaben:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Überlast Schreibpuffer:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Überlast Lesepuffer:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Gesamte Warteschlangengröße:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 Knoten</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Alle (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Beim Herunterladen (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seede (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Abgeschlossen (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Fortgesetzt (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausiert (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktiv (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inaktiv (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Fehlerhaft (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Alle (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Beim Herunterladen (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seede (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Abgeschlossen (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausiert (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Fortgesetzt (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktiv (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inaktiv (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Fehlerhaft (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Download-Priorität</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Verbleibend</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Verfügbarkeit</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Name</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Peers</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>DL-Geschw.</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>UL-Geschw.</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Verhältnis</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Fertig in</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Hinzugefügt am</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Abgeschlossen am</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>DL-Begrenzung</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>UL-Begrenzung</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Heruntergeladen</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Hochgeladen</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>DL in dieser Sitzung</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>UL in dieser Sitzung</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Verbleibend</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktiv seit</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Speicherpfad</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Ratio Limit</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Letzter Seeder (100%) gesehen</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Letzte Aktivität</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Gesamtgröße</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Meldung</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Heruntergeladen</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Tracker-URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aktualisiere ...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Arbeitet</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Noch nicht kontaktiert</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/V</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Arbeitet nicht</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Tracker-URL kopieren</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Neuen Tracker hinzufügen ...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Tracker-URL editieren ...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Tracker editieren</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leecher</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Tracker entfernen</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dialog zum Hinzufügen eines Trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Liste der hinzuzufügenden Tracker (einer pro Zeile):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>vor %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Weise zu</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Angehalten</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Verschiebe</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Seede</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seede</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Eingereiht</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Fehlerhaft</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Herunterladen</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Lade Metadaten</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Überprüfe</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Fehlende Dateien</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Warten auf Überprüfung des Torrents</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Lade</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Überprüfe Fortsetzungsdaten</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Angehalten</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorien</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Begrenzung der Torrent-DL-Rate</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Begrenzung der Torrent-UL-Rate</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Fortsetzen erzwingen</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Anhalten</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Shareverhältnis begrenzen ...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Uploadrate begrenzen ...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Downloadrate begrenzen ...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Nach oben bewegen</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Nach unten bewegen</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>An den Anfang</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>An das Ende</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Speicherort setzen ...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Namen kopieren</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Prüfsumme kopieren</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Erste und letzte Teile zuerst laden</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatisches Torrent-Management</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Neu ...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Erzwinge erneute Überprüfung</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopiere Magnet-Link</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Super-Seeding-Modus</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Umbenennen ...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Der Reihe nach downloaden</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Erzwinge erneute Überprüfung</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Neue Kategorie</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Speicherort</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Neuer Name</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Speicherort setzen</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Erzwinge erneute Anmeldung</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Kategorie ändern</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Speicherpfad</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Begrenzung des Torrent Upload/Download Verhältnisses</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Globale Begrenzung für das Verhältnis verwenden</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Keine Begrenzung für das Verhältnis verwenden</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Begrenzung für das Verhältnis setzen</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>Verhältnis</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Ein fortschrittliches BitTorrent Programm erstellt in C++ und basierend auf dem Qt Toolkit sowie libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Webseite:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum: </translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Bugtracker: </translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Löschen bestätigen</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Dateien auch von der Festplatte löschen</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Löschen bestätigen - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Von URLs laden</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Torrent-Links hinzufügen</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 T %2 h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 Min</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 Min</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Speicherpfad ist leer</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Pfad der Plugins:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL oder lokales Verzeichnis</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Plugin installieren</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Alle Plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Such-Plugins ...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Alle Kategorien</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Suche in:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopiere Beschreibungsseiten-URL</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Zur Beschreibungsseite wechseln</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Ergebnisse (zeige</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Nur Torrent-Namen</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Nur aktivierte</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>von</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Überall</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Deinstallieren</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Neues Plugin installieren</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Hier gibt es neue Suchmaschinen-Plugins:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Installierte Such-Plugins:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Warnung: Achten Sie darauf, die Urheberrechtsgesetze Ihres Landes zu befolgen, wenn Sie von einer dieser Suchmaschinen Torrents herunterladen.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Auf Aktualisierungen prüfen</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Such-Plugins</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leecher</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Suchmaschine</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seeder</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>